@@ -22,8 +22,6 @@ public:
     void setCurrentFormat( const QString& format );
     QString currentProfile();
     bool setCurrentProfile( const QString& profile );
-    QDomDocument customProfile();
-    bool setCustomProfile( const QString& profile, const QDomDocument& document );
     int currentDataRate();
 
 private:
@@ -37,9 +35,6 @@ private:
 private slots:
     void compressionLevelSliderChanged( int quality );
     void compressionLevelSpinBoxChanged( int quality );
-
-signals:
-    void somethingChanged();
 };
 
 #endif // FLAKECODECWIDGET_H
