@@ -102,7 +102,7 @@ void soundkonverter_codec_twolame::showInfo( QWidget *parent )
     dialog->show();
 }
 
-QWidget *soundkonverter_codec_twolame::newCodecWidget()
+CodecWidget *soundkonverter_codec_twolame::newCodecWidget()
 {
     TwoLameCodecWidget *widget = new TwoLameCodecWidget();
     if( lastUsedConversionOptions )
@@ -111,14 +111,14 @@ QWidget *soundkonverter_codec_twolame::newCodecWidget()
         delete lastUsedConversionOptions;
         lastUsedConversionOptions = 0;
     }
-    return qobject_cast<QWidget*>(widget);
+    return qobject_cast<CodecWidget*>(widget);
 }
 
-int soundkonverter_codec_twolame::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
+unsigned int soundkonverter_codec_twolame::convert( const KUrl& inputFile, const KUrl& outputFile, const QString& inputCodec, const QString& outputCodec, ConversionOptions *_conversionOptions, TagData *tags, bool replayGain )
 {
     QStringList command = convertCommand( inputFile, outputFile, inputCodec, outputCodec, _conversionOptions, tags, replayGain );
     if( command.isEmpty() )
-        return -1;
+        return BackendPlugin::UnknownError;
 
     CodecPluginItem *newItem = new CodecPluginItem( this );
     newItem->id = lastId++;
@@ -131,7 +131,7 @@ int soundkonverter_codec_twolame::convert( const KUrl& inputFile, const KUrl& ou
     newItem->process->setShellCommand( command.join(" ") );
     newItem->process->start();
 
-    emit log( newItem->id, command.join(" ") );
+    logCommand( newItem->id, command.join(" ") );
 
     backendItems.append( newItem );
     return newItem->id;
@@ -166,31 +166,6 @@ QStringList soundkonverter_codec_twolame::convertCommand( const KUrl& inputFile,
             command += "-b";
             command += QString::number(conversionOptions->bitrate);
         }
-        if( conversionOptions->samplingRate > 0 )
-        {
-            command += "--samplerate";
-            command += QString::number(conversionOptions->samplingRate);
-        }
-        if( conversionOptions->channels > 0 )
-        {
-            command += "-m";
-            if( conversionOptions->channels == 1 )
-            {
-                command += "m";
-            }
-            else if( conversionOptions->channels == 2 )
-            {
-                command += "j";
-            }
-            else if( conversionOptions->channels == 3 )
-            {
-                command += "s";
-            }
-            else if( conversionOptions->channels == 5 )
-            {
-                command += "d";
-            }
-        }
         if( conversionOptions->pluginName == name() )
         {
             command += conversionOptions->cmdArguments;
@@ -239,12 +214,5 @@ float soundkonverter_codec_twolame::parseOutput( const QString& output )
     return -1;
 }
 
-ConversionOptions *soundkonverter_codec_twolame::conversionOptionsFromXml( QDomElement conversionOptions )
-{
-    ConversionOptions *options = new ConversionOptions();
-    options->fromXml( conversionOptions );
-    return options;
-}
-
 
 #include "soundkonverter_codec_twolame.moc"
